const { execSync } = require('child_process');
const path = require('path');
const fs = require('fs');

// Change to the K6 tests directory
const k6TestsDir = path.join(__dirname, 'k6-tests');
process.chdir(k6TestsDir);

// Function to check if Go is installed
function isGoInstalled() {
  try {
    execSync('go version', { stdio: 'ignore' });
    return true; // Go is installed
  } catch {
    return false; // Go is not installed
  }
}

// Command to generate HTML report
const k6HtmlCommand = 'go run github.com/ValentinGonzalez/k6-html -o report.html results.json'; // Adjust according to your results file

if (!isGoInstalled()) {
  console.error('Error: Go is not installed. Please install Go to generate the HTML report.');
  console.log('You can download it from https://golang.org/dl/');
  process.exit(1); // Exit with an error code
}

try {
  execSync(k6HtmlCommand, { stdio: 'inherit' });
  console.log('Generated HTML report: report.html');
} catch (error) {
  console.error('Error generating report:', error);
}
